==> react-7.11.0.tgz: package/es/ModalBody/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
/**
 * @category containers
 * @component modal
 * @variations collab-ui-react
 */

var ModalBody = function ModalBody(props) {
  var className = props.className,
      other = _objectWithoutProperties(props, ["className"]);

  return React.createElement("div", _extends({
    className: "cui-modal__body" + ("" + (className && " " + className || ''))
  }, other), props.children);
};

ModalBody.propTypes = {
  /**
   * Children components
   */
  children: PropTypes.node,

  /**
   * css class names
   */
  className: PropTypes.string
};
ModalBody.defaultProps = {
  children: null,
  className: ''
};
ModalBody.displayName = 'ModalBody';
export default ModalBody;
/**
* @name Modal Body
*
* @category containers
* @component modal
* @section Modal Body
*
* @js

import {
  Input,
  ModalBody
} from '@collab-ui/react';

export default function Default() {
    return (
      <div className='row'>
        <br />
        <ModalBody>
          <Input
            htmlId='testMe2'
            value='testMe2'
            name='testMe2'
            label='First Input'
            disabled
            placeholder='Disabled Input'
            onChange={() => {}}
            inputHelpText='Field Must be Disabled'
            errorArr={[]}
          />
        </ModalBody>
      </div>
    );
  }

**/

==> react-9.4.0.tgz: package/es/ModalBody/index.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
/**
 * @category containers
 * @component modal
 * @variations collab-ui-react
 */

var ModalBody = function ModalBody(props) {
  var className = props.className,
      other = _objectWithoutPropertiesLoose(props, ["className"]);

  return React.createElement("div", _extends({
    className: "cui-modal__body" + ("" + (className && " " + className || ''))
  }, other), props.children);
};

ModalBody.propTypes = {
  /**
   * Children components
   */
  children: PropTypes.node,

  /**
   * css class names
   */
  className: PropTypes.string
};
ModalBody.defaultProps = {
  children: null,
  className: ''
};
ModalBody.displayName = 'ModalBody';
export default ModalBody;
/**
* @name Modal Body
*
* @category containers
* @component modal
* @section Modal Body
*
* @js

import {
  Input,
  ModalBody
} from '@collab-ui/react';

export default function Default() {
    return (
      <div className='row'>
        <br />
        <ModalBody>
          <Input
            htmlId='testMe2'
            value='testMe2'
            name='testMe2'
            label='First Input'
            disabled
            placeholder='Disabled Input'
            onChange={() => {}}
            inputHelpText='Field Must be Disabled'
            errorArr={[]}
          />
        </ModalBody>
      </div>
    );
  }

**/
